@@ -1,6 +1,6 @@
 from collections import defaultdict
 from pathlib import Path
-from typing import Type, Dict, Any, Generator, Union
+from typing import Type, Dict, Any, Generator, Union, List
 
 from collections_extended import setlist
 from fastapi import Query
@@ -96,6 +96,10 @@ class MeSHKnowledgeParser(KnowledgeParserBase):
     def get_model(cls) -> Type[BaseModel]:
         return MeSHOptionsModel
 
+    @classmethod
+    def get_extensions(cls) -> List[str]:
+        return ["xml", "zip"]
+
 
 # Python program to illustrate the intersection
 # of two lists using set() method
